@@ -1,12 +1,15 @@
+import toolcli
+
 from ctc import binary
 
 
-def get_command_spec():
+def get_command_spec() -> toolcli.CommandSpec:
     return {
         'f': hex_command,
+        'help': 'convert ascii to hex',
         'args': [
             {'name': 'data'},
-            {'name': '--raw', 'kwargs': {'action': 'store_true'}},
+            {'name': '--raw', 'action': 'store_true'},
         ],
     }
 
