@@ -5,10 +5,11 @@ from ctc import rpc
 def get_command_spec():
     return {
         'f': async_block_command,
+        'help': 'summarize block',
         'args': [
-            {'name': 'block', 'kwargs': {'nargs': '?'}},
-            {'name': '--timestamp', 'kwargs': {'type': int}},
-            {'name': '--verbose', 'kwargs': {'action': 'store_true'}},
+            {'name': 'block', 'nargs': '?'},
+            {'name': '--timestamp', 'type': int},
+            {'name': '--verbose', 'action': 'store_true'},
         ],
     }
 
