@@ -6,11 +6,12 @@ from ctc.cli import cli_utils
 def get_command_spec():
     return {
         'f': async_transfers_command,
+        'help': 'output information about ERC20 transfers',
         'args': [
             {'name': 'erc20'},
-            {'name': '--blocks', 'kwargs': {'nargs': '+'}},
-            {'name': '--output', 'kwargs': {'default': 'stdout'}},
-            {'name': '--overwrite', 'kwargs': {'action': 'store_true'}},
+            {'name': '--blocks', 'nargs': '+'},
+            {'name': '--output', 'default': 'stdout'},
+            {'name': '--overwrite', 'action': 'store_true'},
         ],
     }
 
