@@ -8,10 +8,11 @@ from ctc import rpc
 def get_command_spec():
     return {
         'f': async_balance_command,
+        'help': 'output ETH balance of address',
         'args': [
             {'name': 'address'},
             {'name': '--block'},
-            {'name': '--raw', 'kwargs': {'action': 'store_true'}},
+            {'name': '--raw', 'action': 'store_true'},
         ],
     }
 
