@@ -14,9 +14,10 @@ from ctc import rpc
 def get_command_spec():
     return {
         'f': async_pool_command,
+        'help': 'summarize pool',
         'args': [
             {'name': 'pool'},
-            {'name': '--block', 'kwargs': {'default': 'latest'}},
+            {'name': '--block', 'default': 'latest'},
         ],
     }
 
