@@ -1,4 +1,7 @@
+from __future__ import annotations
+
 import typing
+from typing_extensions import TypedDict
 
 from ctc import spec
 
@@ -6,7 +9,7 @@ from ctc import spec
 trade_fee = 0.003
 
 
-class PoolTokensMetadata(typing.TypedDict):
+class PoolTokensMetadata(TypedDict):
     x_address: spec.Address
     y_address: spec.Address
     x_symbol: str
@@ -15,13 +18,13 @@ class PoolTokensMetadata(typing.TypedDict):
     y_decimals: int
 
 
-class PoolState(typing.TypedDict):
+class PoolState(TypedDict):
     x_reserves: typing.Union[int, float]
     y_reserves: typing.Union[int, float]
     lp_total_supply: typing.Union[int, float]
 
 
-class PoolStateByBlock(typing.TypedDict):
+class PoolStateByBlock(TypedDict):
     x_reserves: list[typing.Union[int, float]]
     y_reserves: list[typing.Union[int, float]]
     lp_total_supply: list[typing.Union[int, float]]
